Package: condformat
Type: Package
Title: Conditional Formatting in Data Frames
Version: 0.10.1
Date: 2023-10-08
Authors@R: person(given = "Sergio", family = "Oller Moreno",
                  email = "sergioller@gmail.com", role = c("aut", "cph", "cre"),
                  comment = c(ORCID = "0000-0002-8994-1549"))
URL: https://zeehio.github.io/condformat/,
        https://github.com/zeehio/condformat
BugReports: https://github.com/zeehio/condformat/issues
Description: Apply and visualize conditional formatting to data frames in R.
    It renders a data frame with cells formatted according to
    criteria defined by rules, using a tidy evaluation syntax. The table is
    printed either opening a web browser or within the 'RStudio' viewer if
    available. The conditional formatting rules allow to highlight cells
    matching a condition or add a gradient background to a given column. This
    package supports both 'HTML' and 'LaTeX' outputs in 'knitr' reports, and
    exporting to an 'xlsx' file.
License: BSD_3_clause + file LICENSE
NeedsCompilation: no
Imports: dplyr (>= 0.7.7), grDevices, gridExtra (>= 2.3), gtable (>=
        0.2.0), htmlTable (>= 1.9), htmltools (>= 0.3.6), knitr (>=
        1.20), magrittr (>= 1.5), openxlsx (>= 4.1.5), rmarkdown (>=
        1.10), rlang (>= 0.3.0), scales (>= 1.0.0), tibble (>= 1.3.4),
        tidyselect (>= 1.0.0)
Suggests: promises, shiny (>= 1.0.5), testthat (>= 1.0), vdiffr (>=
        1.0.4)
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.2.3
Packaged: 2023-10-08 06:34:48 UTC; sergio
Author: Sergio Oller Moreno [aut, cph, cre]
    (<https://orcid.org/0000-0002-8994-1549>)
Maintainer: Sergio Oller Moreno <sergioller@gmail.com>
Repository: CRAN
Date/Publication: 2023-10-08 07:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 17:14:29 UTC; unix
