# Generated by roxygen2: do not edit by hand

S3method(cf_field_to_css,cf_field_css)
S3method(cf_field_to_css,cf_field_rule_bar_gradient)
S3method(cf_field_to_css,default)
S3method(cf_field_to_gtable,cf_field_rule_bar_gradient)
S3method(cf_field_to_gtable,cf_field_rule_fill_solid)
S3method(cf_field_to_gtable,cf_field_rule_text_bold)
S3method(cf_field_to_gtable,cf_field_rule_text_color)
S3method(cf_field_to_gtable,default)
S3method(cf_field_to_latex,cf_field_rule_fill_solid)
S3method(cf_field_to_latex,cf_field_rule_text_bold)
S3method(cf_field_to_latex,cf_field_rule_text_color)
S3method(cf_field_to_latex,default)
S3method(knit_print,condformat_tbl)
S3method(print,condformat_tbl)
export(cf_field_to_css)
export(cf_field_to_gtable)
export(cf_field_to_latex)
export(condformat)
export(condformat2excel)
export(condformat2excelsheet)
export(condformat2grob)
export(condformat2html)
export(condformat2latex)
export(condformat2widget)
export(condformatOutput)
export(condformat_example)
export(renderCondformat)
export(rule_css)
export(rule_fill_bar)
export(rule_fill_discrete)
export(rule_fill_gradient)
export(rule_fill_gradient2)
export(rule_text_bold)
export(rule_text_color)
export(show_columns)
export(show_rows)
export(theme_caption)
export(theme_grob)
export(theme_htmlTable)
export(theme_htmlWidget)
export(theme_kable)
importFrom(htmlTable,htmlTable)
importFrom(knitr,knit_print)
importFrom(scales,rescale)
importFrom(scales,rescale_mid)
